@@ -31,6 +31,7 @@ import io
 import re
 import time
 import sys
+import shutil
 
 ###########################################
 ########### SCRIPT SETTINGS ###############
@@ -49,6 +50,10 @@ if sys.platform == 'win32': #this is for 64 bits too
                 CONFIG = Path(var, 'RetroArch', 'retroarch.cfg')
 elif sys.platform == 'darwin':
     CONFIG = Path(Path.home(), 'Library', 'Application Support', 'RetroArch', 'config', 'retroarch.cfg')
+elif hasattr(sys, 'getandroidapilevel'):
+    CONFIG = Path("/", "storage", "emulated", "0", "Android", "data", "com.retroarch.aarch64", "files", "retroarch.cfg")
+    if not CONFIG.is_file():
+        CONFIG = Path("/", "storage", "emulated", "0", "Android", "data", "com.retroarch", "files", "retroarch.cfg")
 else: #all the rest based on linux. If they arent based on linux, they'll try the else and fail harmlessly later
     var = os.getenv('XDG_CONFIG_HOME')
     if var:
@@ -79,7 +84,7 @@ def getPath(cfg: Path, setting: str, default_value: str):
         return cfg.parent / fdir
     elif fdir == 'default':
         if default_value:
-            return Path(cfg.parent,default_value)
+            return cfg.parent / default_value
         else:
             return None
     return Path(fdir)
@@ -121,7 +126,7 @@ def mainaux(cfg: Path = typer.Argument(CONFIG, help='Path to the retroarch cfg f
 
     1. Add the games, by loading, then starting the core from retroarch, then 'mass add' all the games (note this isn't the retroarch scanner - it's a functionality of the core GUI - click the arrow next to 'Add Game...' in the classic theme - the retroarch scan directory function should not be used for scummvm games, and the manual scanner is unneeded with this program).
     
-    2. Download the required engine files and extract them to the right dir. I recommend installing the scummvm required files with 'core system files downloader' in retroarch if you're running the normal core¹.
+    2. Download the required engine files and extract them to the right dir. I recommend installing the scummvm required files with 'core system files downloader' in retroarch.
     
     3. Setup the paths to the required files in the scummvm core GUI options.
     
@@ -133,15 +138,9 @@ def mainaux(cfg: Path = typer.Argument(CONFIG, help='Path to the retroarch cfg f
 
     pip install --force-reinstall libretro_scummvm_playlist
     
-    If you'd like to try to download missing coverart until a PR with scummvm names is added to the thumbnail server try to install and use libretrofuzz:
+    If you'd like to try to download missing coverart until a PR with scummvm names is added to the thumbnail server try to install and use libretro-fuzz:
     
     pip install --force-reinstall libretrofuzz
-    
-    ¹ The diablodiab more updated core at http://build.bot.nu/nightly/ requires updated files from scummvm upstream, you can get them with:
-    
-    http://build.bot.nu/assets/system/ScummVM.zip
-    
-    Then extract the zip into the retroarch system directory.
     """
     if not cfg.is_file():
         error(f'Invalid Retroarch cfg file: {cfg}')
@@ -189,10 +188,13 @@ def mainaux(cfg: Path = typer.Argument(CONFIG, help='Path to the retroarch cfg f
         raise typer.Exit(code=1)
         
     cores_dir  = getPath(cfg, 'libretro_directory', 'cores')
-    if not cores_dir or not cores_dir.is_dir():
+    if not cores_dir:
         error(f'Invalid retroarch.cfg line: libretro_directory="{cores_dir}"')
         raise typer.Exit(code=1)
-    core = os.path.abspath( Path(cores_dir, 'scummvm_libretro' + ( '.dll' if os.name == 'nt' else '.so' ) ) )
+    core_name = 'scummvm_libretro' \
+                + ( '_android' if hasattr(sys, 'getandroidapilevel') else '' ) \
+                + ( '.dll' if os.name == 'nt' else '.so' )
+    core = os.path.abspath(Path(cores_dir, core_name))
     
     content_dir  = getPath(cfg, 'rgui_browser_directory', None)
     if not content_dir or not content_dir.is_dir():
@@ -200,7 +202,11 @@ def mainaux(cfg: Path = typer.Argument(CONFIG, help='Path to the retroarch cfg f
     
     with open(system) as f:
         text = f.read()
-    
+    def copy(source, target):
+        if hasattr(sys, 'getandroidapilevel'):
+            shutil.copy(source, target)
+        else:
+            os.link(source, target)
     #if the MT32 and CM32L roms exist in the system dir (for instance for dosbox)
     mt32rom1 = Path(system_dir, 'MT32_CONTROL.ROM')
     mt32rom2 = Path(system_dir, 'MT32_PCM.ROM')
@@ -210,16 +216,16 @@ def mainaux(cfg: Path = typer.Argument(CONFIG, help='Path to the retroarch cfg f
         target1 = Path(extra_dir, 'MT32_CONTROL.ROM')
         target2 = Path(extra_dir, 'MT32_PCM.ROM')
         if not target1.exists():
-            os.link(mt32rom1, target1)
+            copy(mt32rom1, target1)
         if not target2.exists():
-            os.link(mt32rom2, target2)
+            copy(mt32rom2, target2)
     if cm32rom1.is_file() and cm32rom2.is_file():
         target1 = Path(extra_dir, 'CM32L_CONTROL.ROM')
         target2 = Path(extra_dir, 'CM32L_PCM.ROM')
         if not target1.exists():
-            os.link(cm32rom1, target1)
+            copy(cm32rom1, target1)
         if not target2.exists():
-            os.link(cm32rom2, target2)
+            copy(cm32rom2, target2)
     
     #write scummvm core specific paths so the user doesn't have to
     soundfont = Path(extra_dir, 'Roland_SC-55.sf2')
@@ -244,6 +250,7 @@ def mainaux(cfg: Path = typer.Argument(CONFIG, help='Path to the retroarch cfg f
         'scan_search_recursively': True,
         'scan_search_archives': False,
         'scan_filter_dat_content': False,
+        'scan_overwrite_playlist': True,
         'items': []
     }
     invalid_paths = []
